Find the columns that have more than one value
interesting_cols.RdFind the columns that have more than one value
Usage
interesting_cols(x, keep_anyway = character(0), ...)Value
An object of the same class as x with boring columns
taken out and the duplicated values placed in an attribute called
"boring".
Examples
interesting_cols(data.frame(A=1:2, B=2))
#> A
#> 1 1
#> 2 2
attr(interesting_cols(data.frame(A=1:2, B=2)), "boring")
#> B
#> 1 2