Return the minimum of the differences of x for the first value after the choices.
mindiff_after.RdReturn the minimum of the differences of x for the first value after the choices.
Usage
mindiff_after(x, choices, include_zero = TRUE, none = c("negative", "na"))Value
A vector the same length as x with the minimum difference
between x and any value of choices. If choices has
length 0, then return a vector of NA the same length as x
(with a warning).