Extract the legend from the first figure, remove the legends from all plots, and put the legend at the end.
plot_grid_one_legend.RdExtract the legend from the first figure, remove the legends from all plots, and put the legend at the end.
Value
A list of the ggplot2 objects (suitable for the plotlist
argument of cowplot::plot_grid)
See also
Other plot legend helpers:
extract_ggplot_legend(),
remove_ggplot_legend()